@@ -10,15 +10,15 @@
 #include "breeze.h"
 #include "breezesettings.h"
 
-#include <KDecoration2/DecoratedClient>
-#include <KDecoration2/Decoration>
-#include <KDecoration2/DecorationSettings>
+#include <KDecoration3/DecoratedWindow>
+#include <KDecoration3/Decoration>
+#include <KDecoration3/DecorationSettings>
 
 #include <QPalette>
 #include <QVariant>
 #include <QVariantAnimation>
 
-namespace KDecoration2
+namespace KDecoration3
 {
 class DecorationButton;
 class DecorationButtonGroup;
@@ -26,19 +26,15 @@ class DecorationButtonGroup;
 
 namespace Breeze
 {
-class Decoration : public KDecoration2::Decoration
+class Decoration : public KDecoration3::Decoration
 {
     Q_OBJECT
 
 public:
-    //* constructor
     explicit Decoration(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    ~Decoration() override;
 
-    //* destructor
-    virtual ~Decoration();
-
-    //* paint
-    void paint(QPainter *painter, const QRect &repaintRegion) override;
+    void paint(QPainter *painter, const QRectF &repaintRegion) override;
 
     //* internal settings
     InternalSettingsPtr internalSettings() const
@@ -52,7 +48,7 @@ public:
     }
 
     //* caption height
-    int captionHeight() const;
+    qreal captionHeight() const;
 
     //* button size
     int buttonSize() const;
@@ -106,30 +102,32 @@ private Q_SLOTS:
     void updateTitleBar();
     void updateAnimationState();
     void onTabletModeChanged(bool mode);
+    void updateScale();
 
 private:
     //* return the rect in which caption will be drawn
-    QPair<QRect, Qt::Alignment> captionRect() const;
+    QPair<QRectF, Qt::Alignment> captionRect() const;
 
     void createButtons();
-    void paintTitleBar(QPainter *painter, const QRect &repaintRegion);
+    void paintTitleBar(QPainter *painter, const QRectF &repaintRegion);
     void updateShadow();
-    std::shared_ptr<KDecoration2::DecorationShadow> createShadowObject(const float strengthScale);
+    std::shared_ptr<KDecoration3::DecorationShadow> createShadowObject(const float strengthScale);
     void setScaledCornerRadius();
 
     //*@name border size
     //@{
-    int borderSize(bool bottom = false) const;
+    qreal borderSize(bool bottom, qreal scale) const;
     inline bool hasBorders() const;
     inline bool hasNoBorders() const;
     inline bool hasNoSideBorders() const;
+    QMarginsF bordersFor(qreal scale) const;
     //@}
 
     inline bool outlinesEnabled() const;
 
     InternalSettingsPtr m_internalSettings;
-    KDecoration2::DecorationButtonGroup *m_leftButtons = nullptr;
-    KDecoration2::DecorationButtonGroup *m_rightButtons = nullptr;
+    KDecoration3::DecorationButtonGroup *m_leftButtons = nullptr;
+    KDecoration3::DecorationButtonGroup *m_rightButtons = nullptr;
 
     //* active state change animation
     QVariantAnimation *m_animation;
@@ -150,7 +148,7 @@ bool Decoration::hasBorders() const
     if (m_internalSettings && m_internalSettings->mask() & BorderSize) {
         return m_internalSettings->borderSize() > InternalSettings::BorderNoSides;
     } else {
-        return settings()->borderSize() > KDecoration2::BorderSize::NoSides;
+        return settings()->borderSize() > KDecoration3::BorderSize::NoSides;
     }
 }
 
@@ -159,7 +157,7 @@ bool Decoration::hasNoBorders() const
     if (m_internalSettings && m_internalSettings->mask() & BorderSize) {
         return m_internalSettings->borderSize() == InternalSettings::BorderNone;
     } else {
-        return settings()->borderSize() == KDecoration2::BorderSize::None;
+        return settings()->borderSize() == KDecoration3::BorderSize::None;
     }
 }
 
@@ -168,52 +166,51 @@ bool Decoration::hasNoSideBorders() const
     if (m_internalSettings && m_internalSettings->mask() & BorderSize) {
         return m_internalSettings->borderSize() == InternalSettings::BorderNoSides;
     } else {
-        return settings()->borderSize() == KDecoration2::BorderSize::NoSides;
+        return settings()->borderSize() == KDecoration3::BorderSize::NoSides;
     }
 }
 
 bool Decoration::isMaximized() const
 {
-    return client()->isMaximized() && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return window()->isMaximized() && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isMaximizedHorizontally() const
 {
-    return client()->isMaximizedHorizontally() && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return window()->isMaximizedHorizontally() && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isMaximizedVertically() const
 {
-    return client()->isMaximizedVertically() && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return window()->isMaximizedVertically() && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isLeftEdge() const
 {
-    const auto c = client();
-    return (c->isMaximizedHorizontally() || c->adjacentScreenEdges().testFlag(Qt::LeftEdge)) && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return (window()->isMaximizedHorizontally() || window()->adjacentScreenEdges().testFlag(Qt::LeftEdge))
+        && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isRightEdge() const
 {
-    const auto c = client();
-    return (c->isMaximizedHorizontally() || c->adjacentScreenEdges().testFlag(Qt::RightEdge)) && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return (window()->isMaximizedHorizontally() || window()->adjacentScreenEdges().testFlag(Qt::RightEdge))
+        && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isTopEdge() const
 {
-    const auto c = client();
-    return (c->isMaximizedVertically() || c->adjacentScreenEdges().testFlag(Qt::TopEdge)) && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return (window()->isMaximizedVertically() || window()->adjacentScreenEdges().testFlag(Qt::TopEdge)) && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isBottomEdge() const
 {
-    const auto c = client();
-    return (c->isMaximizedVertically() || c->adjacentScreenEdges().testFlag(Qt::BottomEdge)) && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return (window()->isMaximizedVertically() || window()->adjacentScreenEdges().testFlag(Qt::BottomEdge))
+        && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::hideTitleBar() const
 {
-    return m_internalSettings->hideTitleBar() && !client()->isShaded();
+    return m_internalSettings->hideTitleBar() && !window()->isShaded();
 }
 
 bool Decoration::outlinesEnabled() const
