@@ -1,11 +1,11 @@
-#ifndef breezesettingsprovider_h
-#define breezesettingsprovider_h
 /*
  * SPDX-FileCopyrightText: 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
+#pragma once
+
 #include "breeze.h"
 #include "breezedecoration.h"
 #include "breezesettings.h"
@@ -53,5 +53,3 @@ private:
 };
 
 }
-
-#endif
