@@ -1,5 +1,3 @@
-#ifndef breezeconfigwidget_h
-#define breezeconfigwidget_h
 //////////////////////////////////////////////////////////////////////////////
 // breezeconfigurationui.h
 // -------------------
@@ -9,6 +7,8 @@
 // SPDX-License-Identifier: MIT
 //////////////////////////////////////////////////////////////////////////////
 
+#pragma once
+
 #include "breeze.h"
 #include "breezeexceptionlistwidget.h"
 #include "breezesettings.h"
@@ -29,7 +29,7 @@ class ConfigWidget : public KCModule
 
 public:
     //* constructor
-    explicit ConfigWidget(QWidget *, const QVariantList &);
+    explicit ConfigWidget(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
 
     //* destructor
     virtual ~ConfigWidget() = default;
@@ -48,10 +48,6 @@ protected Q_SLOTS:
     //* update changed state
     virtual void updateChanged();
 
-protected:
-    //* set changed state
-    void setChanged(bool);
-
 private:
     //* ui
     Ui_BreezeConfigurationUI m_ui;
@@ -67,5 +63,3 @@ private:
 };
 
 }
-
-#endif
