@@ -34,7 +34,7 @@ public:
     }
 
     //* enability
-    virtual bool enabled() const
+    [[nodiscard]] virtual bool enabled() const
     {
         return _enabled;
     }
@@ -46,7 +46,7 @@ public:
     }
 
     //* duration
-    virtual int duration() const
+    [[nodiscard]] virtual int duration() const
     {
         return _duration;
     }
