@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef breezespinboxengine_h
-#define breezespinboxengine_h
+#pragma once
 
 #include "breezebaseengine.h"
 #include "breezedatamap.h"
@@ -26,7 +25,7 @@ public:
     }
 
     //* register widget
-    bool registerWidget(QWidget *);
+    bool registerWidget(QObject *target);
 
     //* state
     bool updateState(const QObject *object, QStyle::SubControl subControl, bool value)
@@ -86,5 +85,3 @@ private:
 };
 
 }
-
-#endif
